@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 translator
 ~~~~~~~~~~
 
-Definies the interaction with the translation service.
+Defines the interaction with the translation service.
 Since the program interfaces with the google web service, this
 module deals with the client side logic of pushing the translation request
 to the the server.
-'''
+"""
 
 from __future__ import print_function, unicode_literals
 
@@ -16,10 +16,10 @@ import json
 from functools import wraps
 
 try:
-    from urllib.request import urlopen, Request
+    from urllib.request import urlopen, Request, quote
     from urllib.parse import urlencode
 except ImportError:
-    from urllib2 import urlopen, Request
+    from urllib2 import urlopen, Request, quote
     from urllib import urlencode
 
 __all__ = [
@@ -40,6 +40,7 @@ def push_url(site):
     Returns a dict response object from the server containing the translated
     text and metadata of the request body
     '''
+
     @wraps(site)
     def connection(*args, **kwargs):
         agent = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.9; rv:27.0) Gecko/20100101 Firefox/27.0'
@@ -58,7 +59,7 @@ def push_url(site):
 
 @push_url
 def translator(source, target, phrase):
-    '''
+    """
     Returns the url encoded string that will be pushed to the translation
     server for parsing.
 
@@ -83,7 +84,7 @@ def translator(source, target, phrase):
         >>> translator('en', 'zh-TW', 'Hello World!')
             '你好世界！'
 
-    '''
+    """
     base = 'http://translate.google.com/translate_a/t'
     params = urlencode({
         'client': 'webapp',
@@ -98,7 +99,8 @@ def translator(source, target, phrase):
 
 
 def coroutine(func):
-    '''Coroutine decorator primes first call to next'''
+    """Coroutine decorator primes first call to next"""
+
     @wraps(func)
     def initialization(*args, **kwargs):
         start = func(*args, **kwargs)
@@ -107,31 +109,32 @@ def coroutine(func):
         except AttributeError:
             start.next()
         return start
+
     return initialization
 
 
 @coroutine
 def text_sink(source, dest):
-    '''Coroutine end-point. Outputs text stream into translator'''
+    """Coroutine end-point. Outputs text stream into translator"""
     while True:
         line = (yield)
         translation = translator(source, dest, line)['sentences']
         for line in translation:
-            print(line['trans'].encode('utf-8').decode('utf-8'), end='')
+            print(line['trans'], end='')
 
 
 # Make less http requests by chunking.
 # Google maxes chunks sizes around 2k characters
 @coroutine
 def spooler(iterable):
-    '''Consumes text stream and spools into larger chunk for processing'''
+    """Consumes text stream and spools into larger chunk for processing"""
     try:
         while True:
             wordcount, spool = 0, str()
-            while wordcount < 1000:
+            while wordcount < 1500:
                 stream = (yield)
                 spool += stream
-                wordcount += len(stream)
+                wordcount += len(quote(stream).encode('utf-8'))
             else:
                 iterable.send(spool)
     finally:
@@ -140,7 +143,7 @@ def spooler(iterable):
 
 
 def source(target):
-    '''Coroutine start point. Produces text stream and forwards to consumers'''
+    """Coroutine start point. Produces text stream and forwards to consumers"""
     for line in sys.stdin:
         target.send(line)
     target.close()
